@@ -1,7 +1,10 @@
 use Test;
 use Config;
-BEGIN { plan tests => 3 };
-for(<<TEST1,<<TEST2){
+use strict;
+
+BEGIN { plan tests => 5 };
+
+for([<<TEST1],[<<TEST2,sub{-s 'test.tmp'==26037}],[<<TEST3,sub{open my $read,'<','test.tmp' or die "Can't open test.tmp - $!";((<$read>)[1],close $read)[0] eq "S\n"}]){
 use Acme::Morse::Audible;
 MThd      ` MTrk     Y  @VP V @VP V @VP@V @VP@V @VP V @VP@V @VP V @VP@V @VP@V @VP V @VP@V @VP V @VP@V @VP@V @VP@V @VP@V  /
 TEST1
@@ -14,10 +17,16 @@ print <<Message;
 (The first telegraphic message. Dispatched by Samuel F. B. Morse on May 24, 1844 from Washington D.C. to Baltimore.)
 Message
 TEST2
-open my $test,'>','test.tmp';
-print $test $_;
+no Acme::Morse::Audible;
+MThd      ` MTrk     Y  @VP V @VP V @VP@V @VP@V @VP V @VP@V @VP V @VP@V @VP@V @VP V @VP@V @VP V @VP@V @VP@V @VP@V @VP@V  /
+TEST3
+
+open my $test,'>','test.tmp' or die "Can't open test.tmp - $!";
+binmode($test);
+print $test $$_[0];
 close $test;
+
 ok(!system "$Config{perlpath} -I".(join ' -I',@INC).' test.tmp');
+ok($$_[1]) if $$_[1];
 }
-ok(-s 'test.tmp' == 26038);
 unlink 'test.tmp';
